@@ -20,6 +20,7 @@
 # 15. aux.traceratio.max   : compute trace ratio problem for maximal basis
 # 16. aux.pinv             : use SVD and NumPy scheme
 # 17. aux.bicgstab         : due to my stupidity, now Rlinsolve can't be used.
+# 18. aux_oosprocess       : data processign for oos prediction
 
 #  ------------------------------------------------------------------------
 # 0. AUX.TYPECHECK
@@ -52,26 +53,31 @@ aux.typecheck <- function(data, verbose=FALSE){
 #  ------------------------------------------------------------------------
 # 1. AUX.PREPROCESS
 #  ------------------------------------------------------------------------
-#' Centering, decorrelating, or whitening of the data
+#' Preprocessing the data
 #'
-#' \code{aux.preprocess} can perform one of three popular operations; centering, decorrelating,
-#'  and whitening of data. See below for more details.
+#' \code{aux.preprocess} can perform one of following operations; \code{"center"}, \code{"scale"},
+#' \code{"cscale"}, \code{"decorrelate"} and \code{"whiten"}. See below for more details.
 #'
-#' \code{"center"} option subtracts mean of each column so that every variable has
-#' mean 0. After centering, option \code{"decorrelate"} sets the data matrix
-#' to have diagonal covariance terms only. \code{"whiten"} option sets the sample
-#' covariance to have all diagonal terms equal to 1, equally weighting each variable.
+#'  @section Operations:
+#'  We have following operations,
+#'  \describe{
+#'  \item{\code{"center"}}{subtracts mean of each column so that every variable has mean \eqn{0}.}
+#'  \item{\code{"scale"}}{turns each column corresponding to variable have variance \eqn{1}.}
+#'  \item{\code{"cscale"}}{combines \code{"center"} and \code{"scale"}.}
+#'  \item{\code{"decorrelate"}}{\code{"center"} and sets its covariance term having diagonal entries only.}
+#'  \item{\code{"whiten"}}{\code{"decorrelate"} and sets all diagonal elements be \eqn{1}.}
+#'  }
 #'
 #' @param data an \eqn{(n\times p)} matrix or data frame whose rows are observations
 #' and columns represent independent variables.
-#' @param type one of "center", "decorrelate", or "whiten". See below for more details.
+#' @param type one of \code{"center"}, \code{"scale"}, \code{"cscale"}, \code{"decorrelate"} or \code{"whiten"}.
 #' @return named list containing:
 #' \describe{
 #' \item{pX}{an \eqn{(n\times p)} matrix after preprocessing in accordance with \code{type} parameter}
 #' \item{info}{a list containing \itemize{
 #' \item \code{type:} name of preprocessing procedure.
 #' \item \code{mean:} a mean vector of length \eqn{p}.
-#' \item \code{multiplier:} a \eqn{(p\times p)} matrix for "decorrelate" or "whiten" or 1 for "center".}}
+#' \item \code{multiplier:} a \eqn{(p\times p)} matrix or 1 for "center".}}
 #' }
 #'
 #' @examples
@@ -79,22 +85,27 @@ aux.typecheck <- function(data, verbose=FALSE){
 #' ## Generate data
 #' X = aux.gensamples()
 #'
-#' ## 3 types of preprocessing
+#' ## 5 types of preprocessing
 #' X_center = aux.preprocess(X)
+#' X_scale  = aux.preprocess(X,type="scale")
+#' X_cscale = aux.preprocess(X,type="cscale")
 #' X_decorr = aux.preprocess(X,type="decorrelate")
 #' X_whiten = aux.preprocess(X,type="whiten")
 #'
 #' ## Check with Covariance matrix
-#' par(mfrow=c(1,3))
-#' image(cov(X_center$pX),zlim=c(-50,50)); title("center");
-#' image(cov(X_decorr$pX),zlim=c(-50,50)); title("decorrelate");
-#' image(cov(X_whiten$pX),zlim=c(-50,50)); title("whitening")
+#' par(mfrow=c(2,3))
+#' image(cov(X)[,3:1],          zlim=c(-5,5)); title("original covariance")
+#' image(cov(X_center$pX)[,3:1],zlim=c(-5,5)); title("opt::center")
+#' image(cov(X_scale$pX)[,3:1], zlim=c(-5,5)); title("opt::scale")
+#' image(cov(X_cscale$pX)[,3:1],zlim=c(-5,5)); title("opt::cscale")
+#' image(cov(X_decorr$pX)[,3:1],zlim=c(-5,5)); title("opt::decorrelate")
+#' image(cov(X_whiten$pX)[,3:1],zlim=c(-5,5)); title("opt::whiten")
 #' }
 #'
 #' @rdname aux_preprocess
 #' @author Kisung You
 #' @export
-aux.preprocess <- function(data,type="center"){
+aux.preprocess <- function(data,type=c("center","scale","cscale","decorrelate","whiten")){
   # data : (n-by-d)
   #   ARMA with CPP
   #   input & output are (d-by-n)
@@ -106,42 +117,111 @@ aux.preprocess <- function(data,type="center"){
   } else {
     warning("WARNING : input should be either dataframe or matrix.")
   }
+  type = match.arg(type)
 
-  # 'center','decorrelate', or 'whiten'
-  if (!is.element(type,c("center","decorrelate","whiten"))){
-    stop("* aux.preprocess: 'type' should be one of 3 options; center, decorrelate, or whiten.")
-  }
-  matoutput = tryCatch(
-    {
-      if (type=="center"){
-        aux_preprocess(matinput,as.integer(1))
-      } else if (type=="decorrelate"){
-        aux_preprocess(matinput,as.integer(2))
-      } else {
-        aux_preprocess(matinput,as.integer(3))
-      }
-    }, error=function(cond){
-      return(NA)
-    }, warning=function(cond){
-      return(NA)
+  ## two added methods : 'scale' and 'cscale'
+  if (type=="scale"){ # add 1 : "scale"
+    tmpdata = t(matinput)
+    p       = ncol(tmpdata)
+
+    multiplier = rep(0,p)
+    for (i in 1:p){
+      multiplier[i] = 1/stats::sd(as.vector(tmpdata[,i]))
     }
-  )
-  if (length(matoutput)==1){
-    if (is.na(matoutput)){
-      result = NA
-      return(result)
-    }
-  } else {
-    # now we have 2 lists
-    info   = list()
-    info$type = matoutput$type
-    info$mean = matoutput$mean
-    info$multiplier = matoutput$multiplier
+    info = list()
+    info$type = "scale"
+    info$mean = rep(0,p)
+    info$multiplier = diag(multiplier)
 
     result = list()
-    result$pX = t(matoutput$output)
+    result$pX = tmpdata%*%diag(multiplier)
     result$info = info
     return(result)
+  } else if (type=="cscale"){ # add 2 : "center" + "scale"
+    tmpdata = t(matinput)
+    p       = ncol(tmpdata)
+
+    infomean = as.double(colMeans(tmpdata))
+    infomultiplier = rep(0,p)
+    for (i in 1:p){
+      infomultiplier[i] = 1/stats::sd(as.vector(tmpdata[,i]))
+    }
+    info = list()
+    info$type = "cscale"
+    info$mean = infomean
+    info$multiplier = diag(infomultiplier)
+
+    outdata = array(0,c(nrow(tmpdata),p)) # mean substraction
+    for (i in 1:nrow(tmpdata)){
+      outdata[i,] = as.vector(tmpdata[i,])-infomean
+    }
+
+    result = list()
+    result$pX   = (outdata%*%diag(infomultiplier))
+    result$info = info
+    return(result)
+  } else {
+    # original methods
+    # 'center','decorrelate', or 'whiten'
+    matoutput = tryCatch(
+      {
+        if (type=="center"){
+          aux_preprocess(matinput,as.integer(1))
+        } else if (type=="decorrelate"){
+          aux_preprocess(matinput,as.integer(2))
+        } else {
+          aux_preprocess(matinput,as.integer(3))
+        }
+      }, error=function(cond){
+        return(NA)
+      }, warning=function(cond){
+        return(NA)
+      }
+    )
+    if (length(matoutput)==1){
+      if (is.na(matoutput)){
+        result = NA
+        return(result)
+      }
+    } else {
+      # now we have 2 lists
+      info   = list()
+      info$type = matoutput$type
+      info$mean = matoutput$mean
+      info$multiplier = matoutput$multiplier
+
+      result = list()
+      result$pX = t(matoutput$output)
+      result$info = info
+      return(result)
+    }
+  }
+}
+#' @keywords internal
+#' @noRd
+aux.preprocess.hidden <- function(data,type=c("null","center","scale","cscale","decorrelate","whiten"),algtype=c("linear","nonlinear")){
+  ## minimal preprocessing
+  pptype    = match.arg(type)
+  ppalgtype = match.arg(algtype)
+
+  ## null is mine !
+  n = nrow(data)
+  p = ncol(data)
+  if (type=="null"){
+    info = list()
+    info$type = "null"
+    info$mean = rep(0,p)
+    info$multiplier = 1
+
+    result      = list()
+    result$pX   = data
+    result$info = info
+    result$info$algtype = ppalgtype
+    return(result)
+  } else {
+    result = aux.preprocess(data,type=pptype)
+    result$info$algtype = ppalgtype
+    return(result)
   }
 }
 
@@ -600,6 +680,7 @@ aux.shortestpath <- function(dist){
 #' @keywords internal
 aux.MaxMinLandmark <- function(X,npoints,pdflag=FALSE){
   # 5-1. setting
+  npoints = as.integer(npoints)
   if (nrow(X)<=npoints){
     stop("ERROR : npoints should be smaller than the total number of original data points.")
   }
@@ -1388,3 +1469,27 @@ aux.bicgstab <- function(A,B,xinit=NA,reltol=1e-5,maxiter=1000,
   }
   return(res)
 }
+
+# 18. aux.oospreprocess ---------------------------------------------------
+#     data processing for out-of-sample prediction
+#' @keywords internal
+#' @noRd
+aux.oospreprocess <- function(data, trfinfo){
+  ## 0. parameter
+  n = nrow(data)
+  p = ncol(data)
+  output = array(0,c(n,p))
+  ## 1. extract mean
+  meanvec = as.vector(trfinfo$mean)
+  for (i in 1:n){
+    output[i,] = (as.vector(data[i,])-meanvec)
+  }
+  ## 2. multiplier
+  multiplier = trfinfo$multiplier
+  if (is.matrix(multiplier)){
+    output = output%*%multiplier
+  } else {
+    output = output*multiplier
+  }
+  return(output)
+}
