@@ -3,15 +3,17 @@
 #' LASSO is a popular regularization scheme in linear regression in pursuit of sparsity in coefficient vector
 #' that has been widely used. The method can be used in feature selection in that given the regularization parameter,
 #' it first solves the problem and takes indices of estimated coefficients with the largest magnitude as
-#' meaningful features.
+#' meaningful features by solving
+#' \deqn{\textrm{min}_{\beta} ~ \frac{1}{2}\|X\beta-y\|_2^2 + \lambda \|\beta\|_1}
+#' where \eqn{y} is \code{response} in our method.
 #'
 #' @param X an \eqn{(n\times p)} matrix or data frame whose rows are observations
 #' and columns represent independent variables.
 #' @param response a length-\eqn{n} vector of response variable.
 #' @param ndim an integer-valued target dimension.
 #' @param preprocess an additional option for preprocessing the data.
-#' Default is "null" and other options of "center", "decorrelate" and "whiten"
-#' are supported. See also \code{\link{aux.preprocess}} for more details.
+#' Default is "null". See also \code{\link{aux.preprocess}} for more details.
+#' @param ycenter a logical; \code{TRUE} to center the response variable, \code{FALSE} otherwise.
 #' @param lambda sparsity regularization parameter in \eqn{(0,\infty)}.
 #'
 #' @return a named list containing
@@ -52,13 +54,11 @@
 #' @references
 #' \insertRef{tibshirani_regression_1996}{ADMM}
 #'
-# Tibshirani R (1996). "Regression Shrinkage and Selection via the Lasso.” \emph{Journal of the Royal Statistical Society. Series B (Methodological)},
-# \bold{58}(1), pp. 267-288. ISSN 00359246.
-#'
 #' @rdname linear_LASSO
 #' @author Kisung You
 #' @export
-do.lasso <- function(X, response, ndim=2, preprocess=c("null","center","decorrelate","whiten"), lambda=1.0){
+do.lasso <- function(X, response, ndim=2, preprocess=c("null","center","decorrelate","whiten"),
+                     ycenter=FALSE, lambda=1.0){
   #------------------------------------------------------------------------
   ## PREPROCESSING
   #   1. data matrix
@@ -85,17 +85,16 @@ do.lasso <- function(X, response, ndim=2, preprocess=c("null","center","decorrel
 
   #------------------------------------------------------------------------
   ## COMPUTATION : DATA PREPROCESSING
-  if (algpreprocess=="null"){
-    trfinfo = list()
-    trfinfo$type = "null"
-    pX = as.matrix(X)
-  } else {
-    tmplist = aux.preprocess(X,type=algpreprocess)
-    trfinfo = tmplist$info
-    pX      = tmplist$pX
+  tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="linear")
+  trfinfo = tmplist$info
+  pX      = tmplist$pX
+
+  if (!is.logical(ycenter)){
+    stop("* do.lasso : 'ycenter' should be a logical variable.")
+  }
+  if (ycenter==TRUE){
     response = response-mean(response)
   }
-  trfinfo$algtype = "linear"
 
   #------------------------------------------------------------------------
   ## COMPUTATION : MAIN COMPUTATION FOR LASSO
