@@ -8,8 +8,7 @@
 #' @param label a length-\eqn{n} vector of data class labels.
 #' @param ndim an integer-valued target dimension.
 #' @param preprocess  an additional option for preprocessing the data.
-#' Default is "center" and other options of "decorrelate" and "whiten"
-#' are supported. See also \code{\link{aux.preprocess}} for more details.
+#' Default is "center". See also \code{\link{aux.preprocess}} for more details.
 #'
 #' @return a named list containing
 #' \describe{
@@ -45,7 +44,7 @@
 #' @rdname linear_OLDA
 #' @author Kisung You
 #' @export
-do.olda <- function(X, label, ndim=2, preprocess=c("center","whiten","decorrelate")){
+do.olda <- function(X, label, ndim=2, preprocess=c("center","scale","cscale","whiten","decorrelate")){
   #------------------------------------------------------------------------
   ## PREPROCESSING
   #   1. data matrix
@@ -80,10 +79,9 @@ do.olda <- function(X, label, ndim=2, preprocess=c("center","whiten","decorrelat
   #------------------------------------------------------------------------
   ## COMPUTATION : PRELIMINARY
   #   1. preprocessing of data : note that output pX still has (n-by-p) format
-  tmplist = aux.preprocess(X,type=algpreprocess)
+  tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="linear")
   trfinfo = tmplist$info
   pX      = tmplist$pX
-  trfinfo$algtype = "linear"
 
   #   2. Sb and Sw
   #   2-1. Sb
