@@ -14,8 +14,7 @@
 #'  Default is \code{c("proportion",0.1)}, connecting about 1/10 of nearest data points
 #'  among all data points. See also \code{\link{aux.graphnbd}} for more details.
 #' @param preprocess an additional option for preprocessing the data.
-#' Default is "center" and two other options "decorrelate" and "whiten"
-#' are supported. See also \code{\link{aux.preprocess}} for more details.
+#' Default is "center". See also \code{\link{aux.preprocess}} for more details.
 #'
 #' @return a named list containing
 #' \describe{
@@ -49,7 +48,7 @@
 #'
 #' @seealso \code{\link{do.lpp}}
 #' @export
-do.udp <- function(X, ndim=2, type=c("proportion",0.1), preprocess=c("center","decorrelate","whiten")){
+do.udp <- function(X, ndim=2, type=c("proportion",0.1), preprocess=c("center","scale","cscale","decorrelate","whiten")){
   #------------------------------------------------------------------------
   ## PREPROCESSING
   #   1. data matrix
@@ -65,9 +64,8 @@ do.udp <- function(X, ndim=2, type=c("proportion",0.1), preprocess=c("center","d
   } else {
     algpreprocess = match.arg(preprocess)
   }
-  tmplist = aux.preprocess(X,type=algpreprocess)
+  tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="linear")
   trfinfo = tmplist$info
-  trfinfo$algtype = "linear"
   pX      = tmplist$pX
   #   4. neighborhood creation
   nbdtype = type
